install_node_exporter_from_source

Function install_node_exporter_from_source 

pub fn install_node_exporter_from_source() -> Result<(), Box<dyn Error>>
Installs Node Exporter from source.

This function is used for systems where Node Exporter is not available through the package manager (e.g., CentOS, Fedora).

Errors

Returns an error if any step of the source installation process fails.